@@ -1,4 +1,6 @@
+pub mod pg;
 pub mod query;
+#[cfg(feature = "pg")]
 pub use tokio_postgres::Row;
 pub trait Table
 {
